/* Copyright Faeem Ali 
 * email: kodgehopper@netscape.net
 *
 *----------------------------------------------------------------------
 * This file is part of quickrun 
 *
 *  quickrun is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  quickrun is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with quickrun in the file COPYING; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

#ifndef _COMPLETE_
#define _COMPLETE_

#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <dirent.h>
#include <glib.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <unistd.h>
#include <ctype.h>


/* all path info, dirname, and a list of files from that dir */
typedef struct _PATH_INFO
{
   char *dir_name;
   int show_list; //if 1, list can be shown. if 0, nothing valid to show
   GList *files;
} PATH_INFO;

/* defs to indicate whether we're matching a executable
 * or just some normal file. also used when doing full/partial
 * completions
 */
#define MATCH_ALL 0
#define MATCH_EXECUTABLE 1
#define MATCH_REGULAR_FILE 2
#define MATCH_REGULAR_AND_DIRECTORY 3
#define MATCH_COMPLETE 4 //match full word
#define MATCH_PARTIAL 5 //match partial word

/* shared variables */
extern char *homedir;
extern char *path_string;

/* global vars */
PATH_INFO f_match; //statically stores filename match information
GList *path_list; // list of elements in the path


/* prototypes */
void get_path_files(PATH_INFO *t);
void get_executables();
int is_executable(char *filename, struct stat *file_info, int match_type);
void get_path_files(PATH_INFO *t);
void match_executable(char *cmd);
GList *insert_match_unique(GList *list, char *match);
void cleanup_list(GList **list);
void match_file(char *buffer, int match_type);
char *complete_string(char *t_buffer, char *start, int end, int match_type);
char *get_known_completion(char *buffer, int cursor_pos, char *replacement);
char *get_completions(char *buffer, int cursor_pos);
#endif
